JsonClient class abstract

Constructors

JsonClient()

Properties

baseUri Uri
no setter
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
no setter
interceptor → void Function(Response response)?
Parse error and Throw custom exception here
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

DELETE(String path, {List<String>? queries}) Future
GET(String path, {List<String>? queries}) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
POST(String path, {List<String>? queries, dynamic data}) Future
PUT(String path, {List<String>? queries, dynamic data}) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited